summaryrefslogtreecommitdiffstats
path: root/kexi/widget/tableview/kexicomboboxbase.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/widget/tableview/kexicomboboxbase.h')
-rw-r--r--kexi/widget/tableview/kexicomboboxbase.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/kexi/widget/tableview/kexicomboboxbase.h b/kexi/widget/tableview/kexicomboboxbase.h
index 1433ab0fa..f36dd822c 100644
--- a/kexi/widget/tableview/kexicomboboxbase.h
+++ b/kexi/widget/tableview/kexicomboboxbase.h
@@ -47,12 +47,12 @@ class KEXIDATATABLE_EXPORT KexiComboBoxBase
virtual KexiDB::Field *field() const = 0;
//! \return the original value
- virtual QVariant origValue() const = 0;
+ virtual TQVariant origValue() const = 0;
//! Note: Generally in current implementation this is integer > 0; may be null if no value is set
- virtual QVariant value();
+ virtual TQVariant value();
- virtual QVariant visibleValue();
+ virtual TQVariant visibleValue();
//! Reimplement this and call this impl.: used to clear internal editor
virtual void clear();
@@ -75,29 +75,29 @@ class KEXIDATATABLE_EXPORT KexiComboBoxBase
virtual void slotItemSelected(KexiTableItem*);
//! Call this from slot
- void slotInternalEditorValueChanged(const QVariant &v);
+ void slotInternalEditorValueChanged(const TQVariant &v);
//! Implement this to return the internal editor
- virtual QWidget *internalEditor() const = 0;
+ virtual TQWidget *internalEditor() const = 0;
protected:
- virtual void setValueInternal(const QVariant& add, bool removeOld);
+ virtual void setValueInternal(const TQVariant& add, bool removeOld);
//! Used to select row item for an user-entered value \a v.
//! Only for "lookup table" mode.
- KexiTableItem* selectItemForEnteredValueInLookupTable(const QVariant& v);
+ KexiTableItem* selectItemForEnteredValueInLookupTable(const TQVariant& v);
/*! \return value from \a returnFromColumn related to \a str value from column \a lookInColumn.
If \a allowNulls is true, NULL is returend if no matched column found, else:
\a str is returned.
Example: lookInColumn=0, returnFromColumn=1 --returns user-visible string
for column #1 for id-column #0 */
- QString valueForString(const QString& str, int* row, uint lookInColumn,
+ TQString valueForString(const TQString& str, int* row, uint lookInColumn,
uint returnFromColumn, bool allowNulls = false);
//! sets \a value for the line edit without setting a flag (m_userEnteredValue) that indicates that
//! the text has been entered by hand (by a user)
- void setValueOrTextInInternalEditor(const QVariant& value); //QString& text);
+ void setValueOrTextInInternalEditor(const TQVariant& value); //TQString& text);
//! \return lookup field schema for this combo box, if present and if is valid (i.e. has defined row source)
KexiDB::LookupFieldSchema* lookupFieldSchema() const;
@@ -111,10 +111,10 @@ class KEXIDATATABLE_EXPORT KexiComboBoxBase
virtual void selectAllInInternalEditor() = 0;
//! Implement this to perform "set value" in the internal editor
- virtual void setValueInInternalEditor(const QVariant& value) = 0;
+ virtual void setValueInInternalEditor(const TQVariant& value) = 0;
//! Implement this to return value from the internal editor
- virtual QVariant valueFromInternalEditor() = 0;
+ virtual TQVariant valueFromInternalEditor() = 0;
//! Implement this as signal
virtual void editRequested() = 0;
@@ -122,9 +122,9 @@ class KEXIDATATABLE_EXPORT KexiComboBoxBase
//! Implement this as signal
virtual void acceptRequested() = 0;
- //! Implement this to return a position \a pos mapped from parent (e.g. viewport)
- //! to global coordinates. QPoint(-1, -1) should be returned if this cannot be computed.
- virtual QPoint mapFromParentToGlobal(const QPoint& pos) const = 0;
+ //! Implement this to return a position \a pos mapped from tqparent (e.g. viewport)
+ //! to global coordinates. TQPoint(-1, -1) should be returned if this cannot be computed.
+ virtual TQPoint mapFromParentToGlobal(const TQPoint& pos) const = 0;
//! Implement this to return a hint for popup width.
virtual int popupWidthHint() const = 0;
@@ -136,20 +136,20 @@ class KEXIDATATABLE_EXPORT KexiComboBoxBase
virtual KexiComboBoxPopup *popup() const = 0;
virtual void setPopup(KexiComboBoxPopup *popup) = 0;
- virtual QVariant visibleValueForLookupField();
+ virtual TQVariant visibleValueForLookupField();
void updateTextForHighlightedRow();
- bool handleKeyPressForPopup( QKeyEvent *ke );
+ bool handleKeyPressForPopup( TQKeyEvent *ke );
void acceptPopupSelection();
//! Used by KexiDBComboBox.
void undoChanges();
- QVariant m_visibleValue;
+ TQVariant m_visibleValue;
- QVariant m_userEnteredValue; //!< value (usually a text) entered by hand (by the user)
+ TQVariant m_userEnteredValue; //!< value (usually a text) entered by hand (by the user)
bool m_internalEditorValueChanged : 1; //!< true if user has text or other value inside editor
bool m_slotInternalEditorValueChanged_enabled : 1; //!< Used in slotInternalEditorValueChanged()